=== modified file 'client/drizzletest.cc'
--- client/drizzletest.cc	2010-09-26 08:33:47 +0000
+++ client/drizzletest.cc	2010-10-06 18:22:02 +0000
@@ -783,6 +783,7 @@
     const struct command_arg *arg= &args[i];
     arg->ds->clear();
 
+    bool known_arg_type= true;
     switch (arg->type) {
       /* A string */
     case ARG_STRING:
@@ -817,9 +818,10 @@
       break;
 
     default:
-      assert("Unknown argument type");
+      known_arg_type= false;
       break;
     }
+    assert(known_arg_type);
 
     /* Check required arg */
     if (arg->ds->length() == 0 && arg->required)

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2010-10-04 22:44:31 +0000
+++ drizzled/drizzled.cc	2010-10-06 18:22:02 +0000
@@ -204,7 +204,7 @@
 
 /* static variables */
 
-static bool opt_debugging= 0;
+static bool opt_debugging= false;
 static uint32_t wake_thread;
 static char *drizzled_chroot;
 static const char *default_character_set_name;
@@ -1277,7 +1277,7 @@
   N_("Set up signals usable for debugging"))
   ("lc-time-name", po::value<string>(),
   N_("Set the language used for the month names and the days of the week."))
-  ("log-warnings,W", po::value<string>(),
+  ("log-warnings,W", po::value<bool>(&global_system_variables.log_warnings)->default_value(false)->zero_tokens(),
   N_("Log some not critical warnings to the log file."))  
   ("pid-file", po::value<string>(),
   N_("Pid file used by drizzled."))
@@ -2164,7 +2164,7 @@
   max_system_variables.auto_increment_increment= UINT64_MAX;
   max_system_variables.auto_increment_offset= UINT64_MAX;
   max_system_variables.completion_type= 2;
-  max_system_variables.log_warnings= 1;
+  max_system_variables.log_warnings= true;
   max_system_variables.bulk_insert_buff_size= ULONG_MAX;
   max_system_variables.div_precincrement= DECIMAL_MAX_SCALE;
   max_system_variables.group_concat_max_len= ULONG_MAX;
@@ -2244,16 +2244,6 @@
     exit(0);
   }
 
-  if (vm.count("log-warnings"))
-  {
-    if (vm["log-warnings"].as<string>().empty())
-      global_system_variables.log_warnings++;
-    else if (vm["log-warnings"].as<string>().compare("0"))
-      global_system_variables.log_warnings= 0L;
-    else
-      global_system_variables.log_warnings= atoi(vm["log-warnings"].as<string>().c_str());
-  }
-
   if (vm.count("exit-info"))
   {
     if (vm["exit-info"].as<long>())

=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2010-09-08 22:31:17 +0000
+++ drizzled/error.cc	2010-10-06 18:22:02 +0000
@@ -39,15 +39,8 @@
 class ErrorStringNotFound: public std::exception
 {
 public:
-  ErrorStringNotFound(uint32_t code)
-    : error_num_(code)
+  ErrorStringNotFound()
   {}
-  uint32_t error_num() const
-  {
-    return error_num_;
-  }
-private:
-  uint32_t error_num_;
 };
 
 /*
@@ -202,7 +195,7 @@
   ErrorMessageMap::const_iterator pos= mapping_.find(error_num);
   if (pos == mapping_.end())
   {
-    throw ErrorStringNotFound(error_num);
+    throw ErrorStringNotFound();
   }
   return pos->second;
 }

=== modified file 'drizzled/plugin.h'
--- drizzled/plugin.h	2010-09-27 18:14:40 +0000
+++ drizzled/plugin.h	2010-10-06 18:22:02 +0000
@@ -241,8 +241,18 @@
   the following declarations are for use by plugin implementors
 */
 
+#define DECLARE_DRIZZLE_SYSVAR_BASIC(name, type) struct { \
+  DRIZZLE_PLUGIN_VAR_HEADER;      \
+  type *value;                  \
+  const type def_val;           \
+} DRIZZLE_SYSVAR_NAME(name)
+
 #define DRIZZLE_SYSVAR_BOOL(name, varname, opt, comment, check, update, def) \
-DECLARE_DRIZZLE_SYSVAR_BASIC(name, bool) = { \
+struct { \
+    DRIZZLE_PLUGIN_VAR_HEADER; \
+    bool *value; \
+    bool def_val; \
+  } DRIZZLE_SYSVAR_NAME(name) = { \
   PLUGIN_VAR_BOOL | ((opt) & PLUGIN_VAR_MASK), \
   #name, comment, check, update, &varname, def}
 

=== modified file 'drizzled/sql_bitmap.cc'
--- drizzled/sql_bitmap.cc	2010-10-02 21:15:42 +0000
+++ drizzled/sql_bitmap.cc	2010-10-06 18:22:02 +0000
@@ -35,7 +35,7 @@
     Create a mask with the upper 'unused' bits set and the lower 'used'
     bits clear. The bits within each byte is stored in big-endian order.
    */
-  unsigned char const mask= static_cast<unsigned char const>((~((1 << used) - 1)) & 255); 
+  unsigned char const mask= static_cast<unsigned char>((~((1 << used) - 1)) & 255); 
 
   /*
     The first bytes are to be set to zero since they represent real  bits

=== modified file 'drizzled/table_share.h'
--- drizzled/table_share.h	2010-09-12 04:07:15 +0000
+++ drizzled/table_share.h	2010-10-06 18:22:02 +0000
@@ -217,7 +217,7 @@
 
     if (iter == _keynames.end())
     {
-      position= -1; //historical, required for finding primary key from unique
+      position= UINT32_MAX; //historical, required for finding primary key from unique
       return false;
     }
 

=== modified file 'm4/pandora_warnings.m4'
--- m4/pandora_warnings.m4	2010-10-06 17:46:23 +0000
+++ m4/pandora_warnings.m4	2010-10-06 18:22:02 +0000
@@ -174,11 +174,12 @@
         dnl 2203 is like old-style-cast
         dnl 1684 is like strict-aliasing
         dnl 188 is about using enums as bitfields
-        BASE_WARNINGS="-w1 -Wcheck ${W_FORMAT} -Wp64 -Woverloaded-virtual -Wcast-qual -diag-disable 188,981,2259,2203,1684"
+        dnl 1683 is a warning about _EXPLICIT_ casting, which we want
+        BASE_WARNINGS="-w1 -Wcheck ${W_FORMAT} -Wp64 -Woverloaded-virtual -Wcast-qual -diag-disable 188,981,2259,2203,1683,1684"
       ])
       CC_WARNINGS="${BASE_WARNINGS}"
       CXX_WARNINGS="${BASE_WARNINGS}"
-      PROTOSKIP_WARNINGS="-diag-disable 188,981,967,2259,1684,2203"
+      PROTOSKIP_WARNINGS="-diag-disable 188,981,967,2259,1683,1684,2203"
       
     ],[
       m4_if(PW_LESS_WARNINGS,[no],[

=== modified file 'plugin/mysql_protocol/mysql_password.cc'
--- plugin/mysql_protocol/mysql_password.cc	2010-03-19 22:06:24 +0000
+++ plugin/mysql_protocol/mysql_password.cc	2010-10-06 18:22:02 +0000
@@ -19,7 +19,9 @@
 #include "drizzled/util/convert.h"
 
 using namespace std;
-using namespace drizzled;
+
+namespace drizzled
+{
 
 const char* MySQLPasswordName = "mysql_password";
 
@@ -66,3 +68,5 @@
 
   return str;
 }
+
+}

=== modified file 'plugin/mysql_protocol/mysql_password.h'
--- plugin/mysql_protocol/mysql_password.h	2010-03-18 01:07:53 +0000
+++ plugin/mysql_protocol/mysql_password.h	2010-10-06 18:22:02 +0000
@@ -22,7 +22,7 @@
 namespace drizzled
 {
 
-extern "C" const char* MySQLPasswordName;
+extern const char* MySQLPasswordName;
 
 class MySQLPassword: public drizzled::Item_str_func
 {

=== modified file 'plugin/pbms/src/cslib/CSS3Protocol.cc'
--- plugin/pbms/src/cslib/CSS3Protocol.cc	2010-10-02 21:15:42 +0000
+++ plugin/pbms/src/cslib/CSS3Protocol.cc	2010-10-06 18:22:02 +0000
@@ -546,7 +546,7 @@
 	}
 	catch_(a);
 	con->ms_throw_error = true;
-	data_sent = -1;
+	data_sent = SIZE_MAX;
 	
 	cont_(a);
 	
@@ -569,7 +569,7 @@
 	}
 	catch_(a);
 	con->ms_throw_error = true;
-	data_len = -1;
+	data_len = SIZE_MAX; 
 	
 	cont_(a);
 	return_(data_len);	

=== modified file 'plugin/pbms/src/repository_ms.cc'
--- plugin/pbms/src/repository_ms.cc	2010-10-02 21:15:42 +0000
+++ plugin/pbms/src/repository_ms.cc	2010-10-06 18:22:02 +0000
@@ -742,7 +742,7 @@
 		alias_offset = 0;
 	}
 #else
-	uint32_t alias_hash = -1;
+	uint32_t alias_hash = UINT32_MAX;
 	if (alias || reset_alias) {
 		CSException::throwException(CS_CONTEXT, MS_ERR_NOT_IMPLEMENTED, "No BLOB alias support.");
 	}

=== modified file 'plugin/pbms/src/trans_cache_ms.cc'
--- plugin/pbms/src/trans_cache_ms.cc	2010-10-02 21:15:42 +0000
+++ plugin/pbms/src/trans_cache_ms.cc	2010-10-06 18:22:02 +0000
@@ -285,7 +285,7 @@
 		// The cache is full.
 		tc_OverFlowTID = 0;
 		tc_OverFlow->tid = tid; // save the tid of the first transaction to overflow.
-		tc_OverFlow->log_position = -1;
+		tc_OverFlow->log_position = UINT64_MAX;
 		tc_OverFlow->len = 0; 
 		tc_OverFlow->terminated = MS_Running; 
 		ref = OVERFLOW_TREF;
@@ -320,7 +320,7 @@
 		
 	tc_List[ref].tid = tid;
 	tc_List[ref].len = 0;
-	tc_List[ref].log_position = -1;
+	tc_List[ref].log_position = UINT64_MAX;
 	tc_List[ref].terminated = MS_Running;
 
 	// Update these after initializing the structure because

=== modified file 'plugin/pbxt/src/ha_pbxt.h'
--- plugin/pbxt/src/ha_pbxt.h	2010-10-02 21:15:42 +0000
+++ plugin/pbxt/src/ha_pbxt.h	2010-10-06 18:22:02 +0000
@@ -98,7 +98,7 @@
 	/* override */ int doCommit(drizzled::Session*, bool);
 	/* override */ int doRollback(drizzled::Session*, bool);
 
-	/* override */ uint32_t max_supported_keys(void) const { return -1; }
+	/* override */ uint32_t max_supported_keys(void) const { return UINT32_MAX; }
 	/* override */ uint32_t max_supported_key_part_length(void) const { return MAX_KEY_LENGTH; }
 
 	/* override */ void doGetTableIdentifiers(drizzled::CachedDirectory&,

